
version 15
clear all
capture log close
set more off



cap log close
*log using "$log\02 SOEP Stundenlohn Hauptjob.log", replace


use "$data/merge_08_18.dta", clear
set more off

*Ausnahmen Mindestlohn rausnehmen
drop if ml_ausnahme == 1


*Arbeitszeiten auf max. 48 Stunden begrenzen 
replace AZverein = 48 if AZverein > 48 & AZverein != .
sum AZverein if syear == 2013 [iw = phrf]



*1. Stundenlohn mit tats. Arbeitszeit und bezahlten Überstunden
gen stlohn_tat = . 
replace stlohn_tat = plc0013_h / 4.348 / AZverein if AZverein > 0 & plc0013_h > 0 & AZverein != . & arbeitnehmer == 1
*(ähnlich Brenke-Müller) mit Vormonats-Daten und Angaben zur AZ
*Personen mit vertraglicher AZ nach Umgang mit Überstunden:
*Können diese Überstunden auch in ein sogenanntes Arbeitszeitkonto fließen?
tab plb0194_v1
*Ü-Std. letzten Monat geleistet, wie viele
sum plb0197 if plb0197 > 0 & syear == 2020 , de
*Personen, die Ü-Std. leisten und kein AZ-Konto haben:
replace stlohn_tat = plc0013_h / (4.348 * AZverein + plb0197) if stlohn_tat != . & plb0194_v1 == 2 & plb0197 > 0  & arbeitnehmer == 1


*2. Stundenlohn mit vereinbarter AZ
//Funktioniert nicht: Warum?
gen stlohn_verein =. 
replace plc0013_h = . if plc0013_h == 0
tab syear if plc0013_h != .
replace AZverein = . if AZverein == 0
tab syear if AZverein != .
replace stlohn_verein = plc0013_h / 4.33 / AZverein if AZverein > 0 & plc0013_h > 0  & arbeitnehmer == 1
foreach y of numlist 2013/2019 {
di "Jahr " `y'
sum stlohn_verein if syear == `y' [aweight = phrf]
}



*AN mit fehlender Information über Bruttolohn und Arbeitszeit (vertragl.) als Missing markieren 
*Information wird für Hoch-Gewichtung benötigt


*Missings nur bei Arbeitnehmern inkl. Beamte und Azubis
cap gen missing = 0 if arbeitnehmer == 1
** ### Labels finde ich für das Verständnis immer hilfreich
label define missing 0 "Arbeitnehmer, relevante Vars befüllt" 1 "Arbeitnehmer, missings in relevanten Vars" 
	label values missing missing
	label var missing "Arbeitnehmer mit missing sin relevanten Variablen"


*Füllung von Stundenlohn, sonst missing setzen
replace missing = 1 if stlohn_verein == . & arbeitnehmer == 1
tab missing if syear == 2013 [iw = phrf]

*** ### Soll das "SVB" sein? SVP = Schweizerische Volkspartei

*Verteilung der Missings bei Minijobs und SVP
foreach y of numlist 2008/2018 {
di `y'
tab missing if minijob == 1  & syear == `y' [iw = phrf]
tab missing if minijob != 1  & syear == `y' [iw = phrf]
}

** #### Cross-check, alles okay!
tab missing arbeitnehmer, mis
tab missing minijob, mis
tab missing ml_ausnahme, mis

*Die Missings verteilen bei Minijobs, SVP und Ausnahmen sehr unterschiedlich, deswegen getrennte Umgewichtung



*Knabe et al. (2014), S. 146:
*
*Nicht alle im SOEP Befragten geben vollständig Auskunft über ihre Löhne und Arbeitszeiten. Zur Korrektur der
*fehlenden Beobachtungen nehmen wir an, dass die verbleibenden Beobachtungen in den jeweiligen Untergruppen
*(Vollzeit-, Teilzeitbeschäftigte, Minijobber) gleichermaßen repräsentativ für die fehlenden Beobachtungen sind.21
*Vollzeit: Sozialversicherungspflichtig Beschäftige mit mindestens 30 Wochenstunden regelmäßiger Arbeitszeit; Teilzeit: Sozialversicherungspflichtig
*Beschäftige mit weniger als 30 Wochenstunden; Minijobs: Geringfügig Beschäftigte ohne Studenten und Rentner und ohne Zweitjobs;



*Hoch-Gewichtung der verbleibenden AN ohne Missing, differenziert nach Minijob oder nicht Minijob
*Annahme, dass Missings zufällig streuen 
*Gewichtung anpassen
cap drop phrf_stlohn
gen phrf_stlohn_tat = .
foreach y of numlist 2008/2018 {
*Minijobs ohne Ausnahmen
di "Jahr " `y'
* Gültige Fälle
sum phrf if (missing ==0) & ml_ausnahme == 0 & syear == `y' & minijob == 1 
global gewicht_anpassung1 = r(sum) 
* Ungültige Fälle
sum phrf if (missing ==1) & ml_ausnahme == 0 & syear == `y' & minijob == 1 
global gewicht_anpassung2 = r(sum) 
* Neues Gewicht für befüllte Fälle
replace phrf_stlohn = (1 + $gewicht_anpassung2 / $gewicht_anpassung1) * phrf if (missing ==0) & ml_ausnahme == 0 & syear == `y' & minijob == 1  
*SVP Vollzeit wie bei Knabe et al.
sum phrf if (missing ==0) & ml_ausnahme == 0 & syear == `y' & minijob != 1 & AZverein != . & AZverein >= 30
global gewicht_anpassung1 = r(sum) 
sum phrf if (missing ==1) & ml_ausnahme == 0 & syear == `y' & minijob != 1 & AZverein != . & AZverein >= 30
global gewicht_anpassung2 = r(sum) 
replace phrf_stlohn = (1 + $gewicht_anpassung2 / $gewicht_anpassung1) * phrf if (missing ==0) & ml_ausnahme == 0 & syear == `y' & minijob != 1 & AZverein >= 30
*SVP Teilzeit wie bei Knabe et al.
sum phrf if (missing ==0) & ml_ausnahme == 0 & syear == `y' & minijob != 1 & AZverein != . & AZverein < 30
global gewicht_anpassung1 = r(sum) 
sum phrf if (missing ==1) & ml_ausnahme == 0 & syear == `y' & minijob != 1 & AZverein != . & AZverein < 30
global gewicht_anpassung2 = r(sum) 
replace phrf_stlohn = (1 + $gewicht_anpassung2 / $gewicht_anpassung1) * phrf if (missing ==0) & ml_ausnahme == 0 & syear == `y' & minijob != 1 & AZverein < 30
}

*Anzahl Minijobs und SVP mit und ohne Umgewichtung
*ohne Umgewichtung
tab minijob if syear == 2013 & ml_ausnahme == 0 [iw = phrf]
*Umgewichtung, die hochgerechneten Zahlen sollten sich nicht verändern
*das neue Gewicht wirkt sich nur auf Hochrechnungen mit den Stundenlöhnen aus
tab minijob if syear == 2013 & ml_ausnahme == 0 [iw = phrf_stlohn]


*Erfasste Arbeitnehmer nach Umgewichtung 
tab syear
foreach y of numlist 2008/2018 {
tab syear if syear == `y'  [iw = phrf_stlohn]
}


save "$data/merge_08_18_2.dta", replace




cap log close


