



version 15
clear all
capture log close
set more off


global prog "C:\Users\toralf-pusch\OneDrive - Hans Böckler Stiftung\2022 Mini und Midijobs\SOEP Mini und Midijobs"
global orig "C:\Users\toralf-pusch\OneDrive - Hans Böckler Stiftung\2022 Austauschverzeichnis Marcel Toralf\SOEP_Welle_37\Stata" 
global data "C:\Users\toralf-pusch\OneDrive - Hans Böckler Stiftung\Datensaetze_Arbeitsverzeichnisse\SOEP_Long_Arbeitsverzeichnis"
global log  "C:\Users\toralf-pusch\OneDrive - Hans Böckler Stiftung\2022 Jahrbuch Mindestlohn\SOEP long Arbeitsverzeichnis\log"

*Daten laden
use "$data/merge_08_18_2.dta", clear
set more off

*welle in welle umbenennen, um Code einfach kopieren zu können
rename syear welle

*Alter unter 19 aussortieren
drop if alter <= 18 | alter > 65
*Azubis und Praktikanten aussortieren
*Elternzeit etc.
drop if elternzeit_mutter == 1
*Altersteilzeit lässt sich nicht aussortieren, nur bis 2015 im Datensatz


*Haushalte mit Selbstständigen markieren
cap bysort hid welle: egen Selbst_HH = max(selbst)
replace Selbst_HH = 0 if Selbst_HH != 1
tab Selbst_HH if welle == 2013 [iw = phrf]

*Haushalte mit AN markieren
cap bysort hid welle: egen AN_HH = max(arbeitnehmer)
replace AN_HH = 0 if AN_HH != 1
tab AN_HH if welle == 2013 [iw = phrf]



*ML-Ausnahmen wurden in Datei Stundenlohn gelöscht

*Wie viele AN?
tab arbeitnehmer if welle == 2008 [iw = phrf]
*32192165
tab arbeitnehmer if welle == 2013 [iw = phrf]
*32158358
tab arbeitnehmer if welle == 2018 [iw = phrf]
*35183895

*Wie viele Selbstständige?
tab selbst if welle == 2008 [iw = phrf]
*3,345,183
tab selbst if welle == 2013 [iw = phrf]
*3,582,487
tab selbst if welle == 2018 [iw = phrf]
*3,157,286

*Ostdeutschland 
tab hgnuts1 if welle == 2008 [iw = phrf]
tab hgnuts1 if welle == 2013 [iw = phrf]
cap gen ostdeutschland = 1 if hgnuts1 == 4 | hgnuts1 == 8 | hgnuts1 == 13 | hgnuts1 == 14 | hgnuts1 == 16
replace ostdeutschland = 0 if ostdeutschland != 1 
tab ostdeutschland  if welle == 2008 [iw = phrf]
tab ostdeutschland  if welle == 2013 [iw = phrf]
tab ostdeutschland

*Wie viele Selbstständige in Ostdeutschland?
tab selbst if ostdeutschland == 1 & welle == 2008 [iw = phrf]
*3,345,183
tab selbst if ostdeutschland == 1 & welle == 2013 [iw = phrf]
*3,582,487
tab selbst if ostdeutschland == 1 & welle == 2018 [iw = phrf]
*3,157,286

*Wie viele Selbstständige in Ostdeutschland?
tab selbst if ostdeutschland == 0 & welle == 2008 [iw = phrf]
*3,345,183
tab selbst if ostdeutschland == 0 & welle == 2013 [iw = phrf]
*3,582,487
tab selbst if ostdeutschland == 0 & welle == 2018 [iw = phrf]
*3,157,286


*Missings bei Monatsverdienst
tab plc0013_h if plc0013_h < 0
replace plc0013_h = . if plc0013_h < 0


*zum Vergleich: AN-Zahlen in den Jahren nach ADMIN Statistik

*2008 
*(ANBA Bericht im Verzeichnis)
*27,5 Mio. SVB
*4,9  Mio. ausschließliche Minijobs
*zusammen:
*32,4 Mio., da fehlen aber die Beamten, ca. 2,2 Mio. laut SOEP
*tab arbeitnehmer if emplstatus4 >= 610 & emplstatus4 <= 640 & welle == 2008 [iw = phrf]

*2013
*(ANBA September 2013)
*29,3 Mio. SVB
*4,8  Mio. ausschließliche Minijobs
*zusammen:
*34,1 Mio., da fehlen aber die Beamten, ca. 2,3 Mio. laut SOEP
*tab arbeitnehmer if emplstatus4 >= 610 & emplstatus4 <= 640 & welle == 2013 [iw = phrf]

*2018
*von Webseite https://statistik.arbeitsagentur.de/DE/Navigation/Statistiken/Interaktive-Statistiken/Datenbanken/Datenbanken-BST-Nav.html
*32,9 Mio. SVB
*5,0  Mio. ausschließliche Minijobs
*zusammen:
*36,1 Mio. 


*Einkommensvariablen und OECD-Gewicht dranmergen: ACHTUNG; IN DOROTHEES FILE PREISBEREINIGUNG AUF CPI 2016 
*Bruttoeinkommen, nominal
* ohne Beamtenkorrektur
*	gen hincgrossY = hinclaborY + hincassetY + hincimprentY + hincprivtransfersY + hincpubtransfersY ///*
*					+ hincsocialsecY + hincprivretirementY
*	label variable hincgrossY "jährliches HH-Bruttoeinkommen"

*Nettoeinkommen, nominal
*	gen hincnetY = hinclaborY + hincassetY + hincimprentY + hincprivtransfersY + hincpubtransfersY ///
*					+ hincsocialsecY + hincprivretirementY - hfedtaxesY ///
*					- hsocialsectaxesY 
*					// Entspricht: HH-Arbeitseinkommen + HH-Vermögenseinkommen + imputed Rent + HH-Private Transfers + HH-staatl. Transferleistungen + HH-Renteneineikommen+ HH-priv. Rente - HH-Seuern - HH-Sozailversicherungsabgabem




*Preisbereinigung für die Jahresvariablen rückwirkend (beziehen sich auf Vorjahr also CPI um ein Jahr in die Zukunft geschoben)
foreach l of varlist hincgrossY hincnetY hinclaborY{
replace `l' = `l' * 100 / 85.5 if welle == 2005 + 1
replace `l' = `l' * 100 / 87 if welle == 2006 + 1
replace `l' = `l' * 100 / 89 if welle == 2007 + 1
replace `l' = `l' * 100 / 91.4 if welle == 2008 + 1
replace `l' = `l' * 100 / 91.6 if welle == 2009 + 1
replace `l' = `l' * 100 / 92.7 if welle == 2010 + 1
replace `l' = `l' * 100 / 95 if welle == 2011 + 1
replace `l' = `l' * 100 / 97 if welle == 2012 + 1
replace `l' = `l' * 100 / 98.6 if welle == 2013 + 1
replace `l' = `l' * 100 / 99.3 if welle == 2014 + 1
replace `l' = `l' * 100 / 100 if welle == 2015 + 1
replace `l' = `l' * 100 / 100.4 if welle == 2016 + 1
replace `l' = `l' * 100 / 102.1 if welle == 2017 + 1
replace `l' = `l' * 100 / 104 if welle == 2018 + 1
replace `l' = `l' * 100 / 105.5 if welle == 2019 + 1
replace `l' = `l' * 100 / 105.8 if welle == 2020 + 1
}

*Preisbereinigung für Monatslohn, Stundenlohn
foreach l of varlist plc0013_h stlohn_verein{
replace `l' = `l' * 100 / 85.5 if welle == 2005
replace `l' = `l' * 100 / 87 if welle == 2006
replace `l' = `l' * 100 / 89 if welle == 2007
replace `l' = `l' * 100 / 91.4 if welle == 2008
replace `l' = `l' * 100 / 91.6 if welle == 2009
replace `l' = `l' * 100 / 92.7 if welle == 2010
replace `l' = `l' * 100 / 95 if welle == 2011
replace `l' = `l' * 100 / 97 if welle == 2012
replace `l' = `l' * 100 / 98.6 if welle == 2013
replace `l' = `l' * 100 / 99.3 if welle == 2014
replace `l' = `l' * 100 / 100 if welle == 2015
replace `l' = `l' * 100 / 100.4 if welle == 2016
replace `l' = `l' * 100 / 102.1 if welle == 2017
replace `l' = `l' * 100 / 104 if welle == 2018
replace `l' = `l' * 100 / 105.5 if welle == 2019
replace `l' = `l' * 100 / 105.8 if welle == 2020
}

*Monatsvariablen aus den Jahresvariablen generieren
foreach l of varlist hincgrossY hincnetY hinclaborY{
replace `l' = `l' / 12
}
rename hincgrossY hincgrossM
rename hincnetY hincnetM
rename hinclaborY hinclaborM

*OECD-Äquivalenzgewichtung, Normierung auf Monatswerte
foreach l of varlist hincgrossM hincnetM hinclaborM {
cap gen `l'_oecd = `l' / oecd1 
}

*Vergleich 2013
*Längsgewichte 2013/14 und 2018/19 wegen retrospektivem HH-Einkommen
sum hincgrossM if welle == 2014 [iw = hhrf_laengs_1jahr]
sum hincgrossM_oecd if welle == 2014 [iw = hhrf_laengs_1jahr]






*Nur Arbeitnehmer behalten, wegen Lohnsumme
*keep if arbeitnehmer == 1 

*Anteil unter Mindestlohn, 2013 preisbereinigter Wert für Milo-Schwelle von 2015
gen     mark = 0 if stlohn_verein > 0
replace mark = 1 if stlohn_verein < 8.5  & welle == 2008
replace mark = 1 if stlohn_verein < 8.5  & welle == 2013
*im Jahr 2018 die Deflationierung rückggängig machen
replace mark = 1 if stlohn_verein / 100 * 104 < 8.84 + 0.5 & welle == 2018


*Anteil unter Mindestlohn 2008
tab mark if welle == 2008 [iw = phrf_stlohn]

*Anteil unter Mindestlohn 2013
tab mark if welle == 2013 [iw = phrf_stlohn]

*Anteil unter Mindestlohn 2018
tab mark if welle == 2018 [iw = phrf_stlohn]


*Niedriglohnschwelle
cap gen Niedriglohn = 0 if AN == 1 & stlohn_verein != .
tab Niedriglohn [iw = phrf_stlohn]
*2008
sum stlohn_verein if welle == 2008 & AN == 1 [aw = phrf_stlohn], detail
replace Niedriglohn = 1 if welle == 2008 & AN == 1 & stlohn_verein <= 2/3 * `r(p50)'
tab Niedriglohn if welle == 2008 & AN == 1 [aw = phrf_stlohn]
*2013
sum stlohn_verein if welle == 2013 & AN == 1 [aw = phrf_stlohn], detail
replace Niedriglohn = 1 if welle == 2013 & AN == 1 & stlohn_verein <= 2/3 * `r(p50)'
tab Niedriglohn if welle == 2013 & AN == 1 [aw = phrf_stlohn]
*2018
sum stlohn_verein if welle == 2018 & AN == 1 [aw = phrf_stlohn], detail
replace Niedriglohn = 1 if welle == 2018 & AN == 1 & stlohn_verein <= 2/3 * `r(p50)'
tab Niedriglohn if welle == 2018 & AN == 1 [aw = phrf_stlohn]



*Winsorizing Personendaten

*Monatslöhne Stundenlöhne Arbeitszeit
foreach l of varlist plc0013_h stlohn_verein AZverein{
foreach y of numlist 2008/2019 {
sum `l' if welle == `y'
winsor2 `l' if welle == `y'
sum `l'_w
replace `l' = `l'_w if welle == `y'
drop `l'_w
}
}


*Winsorizing HH-Daten

*HH-Marker bei Person 1 für Haushalts-Variablen
bys hid welle: gen h_mark = _n
tab h_mark if welle == 2013

*Brutto Haushaltseinkommen, Netto Haushaltseinkommen, HH Lohnsumme
foreach l of varlist hincgrossM hincnetM hinclaborM hincgrossM_oecd hincnetM_oecd hinclaborM_oecd {
foreach y of numlist 2008/2019 {
sum `l' if welle == `y'
winsor2 `l' if welle == `y' & h_mark == 1
sum `l'_w
replace `l' = `l'_w if welle == `y'
drop `l'_w
}
}


*Einkommen aus Arbeit sind zu hoch!!!!!!!!
sum hinclaborM if welle == 2009 & h_mark == 1 & (AN_HH == 1 | Selbst_HH == 1) [aw=hhrf_laengs_1jahr]
sum hinclaborM if welle == 2009 & h_mark == 1 & (AN_HH == 1 ) [aw=hhrf_laengs_1jahr]

*Einkommen aus Arbeit selbst generieren
bys hid welle: egen sum_wages = total(plc0013_h)
sum sum_wages


*Tabelle für SOEP EVS Vergleich, Preise von 2015, Haushalte mit AN oder Selbstständigen zwischen 19 und 65 Jahren (Azbis zählen nicht als AN)
*Alle Auswertungen mit Haushaltsgewichten für die Vergleichbarkeit

*Haushaltsdaten

putexcel set "C:\Users\toralf-pusch\OneDrive - Hans Böckler Stiftung\2023 Journal of Economics and Statistics MW\Tabellen\EVS_SOEP", sheet(SOEP, replace) modify
*nach Jahren, erste Tabelle 2008
putexcel B1 = "SOEP 2008"
putexcel C1 = "SOEP 2008"
putexcel D1 = "SOEP 2013"
putexcel E1 = "SOEP 2013"
putexcel F1 = "SOEP 2018"
putexcel G1 = "SOEP 2018"
putexcel B2 = "Mittelwert"
putexcel C2 = "N"
putexcel D2 = "Mittelwert"
putexcel E2 = "N"
putexcel F2 = "Mittelwert"
putexcel G2 = "N"
putexcel A3 = "Haushaltsdaten"
putexcel A4 = "Brutto Haushaltseinkommen"
putexcel A5 = "Brutto Haushaltseinkommen, OECD-gewichtet"
putexcel A6 = "Brutto Arbeitseinkommen im Haushalt"
putexcel A7 = "Netto Haushaltseinkommen"
putexcel A8 = "Netto Haushaltseinkommen, OECD-gewichtet"
putexcel A9 = "Anzahl der Haushalte, hochgerechnet"
local zeilenzaehler = 4
foreach l of varlist hincgrossM hincgrossM_oecd{
sum `l' if welle == 2009 & h_mark == 1 & (AN_HH == 1) [aw=hhrf_laengs_1jahr]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel B`zeilenzaehler' = (`temp')
putexcel C`zeilenzaehler' = (`temp2')
sum `l' if welle == 2014 & h_mark == 1 & (AN_HH == 1) [aw=hhrf_laengs_1jahr]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel D`zeilenzaehler' = (`temp')
putexcel E`zeilenzaehler' = (`temp2')
sum `l' if welle == 2019 & h_mark == 1 & (AN_HH == 1) [aw=hhrf_laengs_1jahr]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel F`zeilenzaehler' = (`temp')
putexcel G`zeilenzaehler' = (`temp2')
local zeilenzaehler = `zeilenzaehler' + 1
}
*Lohnsumme wurde abweichend generiert (SOEP Variable ist zu hoch)
local zeilenzaehler = 6
sum sum_wages if welle == 2008 & h_mark == 1 & (AN_HH == 1) [aw=hhrf]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel B`zeilenzaehler' = (`temp')
putexcel C`zeilenzaehler' = (`temp2')
sum sum_wages if welle == 2013 & h_mark == 1 & (AN_HH == 1) [aw=hhrf]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel D`zeilenzaehler' = (`temp')
putexcel E`zeilenzaehler' = (`temp2')
sum sum_wages if welle == 2018 & h_mark == 1 & (AN_HH == 1) [aw=hhrf]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel F`zeilenzaehler' = (`temp')
putexcel G`zeilenzaehler' = (`temp2')
local zeilenzaehler = 7
*Weiter mit SOEP-generierten Variablen
foreach l of varlist hincnetM hincnetM_oecd{
sum `l' if welle == 2009 & h_mark == 1 & (AN_HH == 1) [aw=hhrf_laengs_1jahr]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel B`zeilenzaehler' = (`temp')
putexcel C`zeilenzaehler' = (`temp2')
sum `l' if welle == 2014 & h_mark == 1 & (AN_HH == 1) [aw=hhrf_laengs_1jahr]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel D`zeilenzaehler' = (`temp')
putexcel E`zeilenzaehler' = (`temp2')
sum `l' if welle == 2019 & h_mark == 1 & (AN_HH == 1) [aw=hhrf_laengs_1jahr]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel F`zeilenzaehler' = (`temp')
putexcel G`zeilenzaehler' = (`temp2')
local zeilenzaehler = `zeilenzaehler' + 1
}
*Anzahl der HH
sum h_mark if welle == 2008 & h_mark == 1 & (AN_HH == 1) [aw=hhrf]
putexcel B`zeilenzaehler' = (`r(sum_w)')
putexcel C`zeilenzaehler' = (`r(N)')
sum h_mark if welle == 2013 & h_mark == 1 & (AN_HH == 1) [aw=hhrf]
putexcel D`zeilenzaehler' = (`r(sum_w)')
putexcel E`zeilenzaehler' = (`r(N)')
sum h_mark if welle == 2018 & h_mark == 1 & (AN_HH == 1) [aw=hhrf]
putexcel F`zeilenzaehler' = (`r(sum_w)')
putexcel G`zeilenzaehler' = (`r(N)')
local zeilenzaehler = `zeilenzaehler' + 1


*Personendaten, mit angepasstem Gewicht (für Missings)

*Bruttomonatsverdienst AN und Selbst
sum plc0013_h if (AN == 1 | selbst == 1) & welle == 2018 [aw=phrf_stlohn]
sum plc0013_h if (AN == 1 | selbst == 1) & welle == 2018 [aw=phrf]
tab selbst if welle == 2018 [iw=phrf]

putexcel A11 = "Personendaten (Arbeitnehmer)"
putexcel A12 = "Bruttomonatsverdienst"
putexcel A13 = "Vereinbarte Wochenarbeitszeit"
putexcel A14 = "Stundenlohn"
putexcel A15 = "Anteil im Mindestlohnbereich"
putexcel A16 = "Anteil Niedriglohn (< 2/3 P50)"
putexcel A17 = "Anzahl der Arbeitnehmer, hochgerechnet"
putexcel A18 = "Personendaten (Selbstständige)"
putexcel A19 = "Bruttomonatsverdienst"
putexcel A20 = "Anzahl der Selbstständigen, hochgerechnet"
local zeilenzaehler = 12
foreach l of varlist plc0013_h {
sum `l' if welle == 2008 & AN == 1 [aw=phrf_stlohn]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel B`zeilenzaehler' = (`temp')
putexcel C`zeilenzaehler' = (`temp2')
sum `l' if welle == 2013 & AN == 1 [aw=phrf_stlohn]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel D`zeilenzaehler' = (`temp')
putexcel E`zeilenzaehler' = (`temp2')
sum `l' if welle == 2018 & AN == 1 [aw=phrf_stlohn]
local temp  = round(`r(mean)',1)
local temp2 = `r(N)'
putexcel F`zeilenzaehler' = (`temp')
putexcel G`zeilenzaehler' = (`temp2')
local zeilenzaehler = `zeilenzaehler' + 1
}
foreach l of varlist AZverein stlohn_verein  {
sum `l' if welle == 2008 & AN == 1 [aw=phrf_stlohn]
local temp  = round(`r(mean)',0.01)
local temp2 = `r(N)'
putexcel B`zeilenzaehler' = (`temp')
putexcel C`zeilenzaehler' = (`temp2')
sum `l' if welle == 2013 & AN == 1 [aw=phrf_stlohn]
local temp  = round(`r(mean)',0.01)
local temp2 = `r(N)'
putexcel D`zeilenzaehler' = (`temp')
putexcel E`zeilenzaehler' = (`temp2')
sum `l' if welle == 2018 & AN == 1 [aw=phrf_stlohn]
local temp  = round(`r(mean)',0.01)
local temp2 = `r(N)'
putexcel F`zeilenzaehler' = (`temp')
putexcel G`zeilenzaehler' = (`temp2')
local zeilenzaehler = `zeilenzaehler' + 1
}
local zeilenzaehler = 15
foreach l of varlist  mark Niedriglohn {
sum `l' if welle == 2008 & AN == 1 [aw=phrf_stlohn]
local temp  = round(100 * `r(mean)',0.1)
putexcel B`zeilenzaehler' = (`temp')
putexcel C`zeilenzaehler' = (`r(N)')
sum `l' if welle == 2013 & AN == 1 [aw=phrf_stlohn]
local temp  = round(100 * `r(mean)',0.1)
putexcel D`zeilenzaehler' = (`temp')
putexcel E`zeilenzaehler' = (`r(N)')
sum `l' if welle == 2018 & AN == 1 [aw=phrf_stlohn]
local temp  = round(100 * `r(mean)',0.1)
putexcel F`zeilenzaehler' = (`temp')
putexcel G`zeilenzaehler' = (`r(N)')
local zeilenzaehler = `zeilenzaehler' + 1
}
*Anzahl der AN hochgerechnet
sum AN if welle == 2008 & AN == 1  [aw=phrf_stlohn]
putexcel B`zeilenzaehler' = (`r(sum_w)')
putexcel C`zeilenzaehler' = (`r(N)')
sum AN if welle == 2013 & AN == 1  [aw=phrf_stlohn]
putexcel D`zeilenzaehler' = (`r(sum_w)')
putexcel E`zeilenzaehler' = (`r(N)')
sum AN if welle == 2018 & AN == 1  [aw=phrf_stlohn]
putexcel F`zeilenzaehler' = (`r(sum_w)')
putexcel G`zeilenzaehler' = (`r(N)')
local zeilenzaehler = `zeilenzaehler' + 2

*Personendaten Selbstständige

*Monatsverdienst
sum plc0013_h if welle == 2008 & selbst == 1  [aw=phrf]
putexcel B`zeilenzaehler' = (`r(mean)')
putexcel C`zeilenzaehler' = (`r(N)')
sum plc0013_h if welle == 2013 & selbst == 1  [aw=phrf]
putexcel D`zeilenzaehler' = (`r(mean)')
putexcel E`zeilenzaehler' = (`r(N)')
sum plc0013_h if welle == 2018 & selbst == 1  [aw=phrf]
putexcel F`zeilenzaehler' = (`r(mean)')
putexcel G`zeilenzaehler' = (`r(N)')
local zeilenzaehler = `zeilenzaehler' + 1

*Anzahl der Selbstständigen hochgerechnet
sum selbst if welle == 2008 & selbst == 1  [aw=phrf]
putexcel B`zeilenzaehler' = (`r(sum_w)')
putexcel C`zeilenzaehler' = (`r(N)')
sum selbst if welle == 2013 & selbst == 1  [aw=phrf]
putexcel D`zeilenzaehler' = (`r(sum_w)')
putexcel E`zeilenzaehler' = (`r(N)')
sum selbst if welle == 2018 & selbst == 1  [aw=phrf]
putexcel F`zeilenzaehler' = (`r(sum_w)')
putexcel G`zeilenzaehler' = (`r(N)')
local zeilenzaehler = `zeilenzaehler' + 1


